@@ -306,10 +306,12 @@ impl IriRefBuf {
 					self.path_mut().normalize();
 				} else {
 					let mut path_buffer = IriRefBuf::default();
+					path_buffer.set_authority(base_iri.authority()); // we set the authority to avoid path disambiguation.
 					if base_iri.authority().is_some() && base_iri.path().is_empty() {
 						path_buffer.set_path("/".try_into().unwrap());
 					} else {
 						path_buffer.set_path(base_iri.path().directory());
+						path_buffer.path_mut().normalize();
 					}
 					path_buffer.path_mut().symbolic_append(self.path());
 					if self.path().is_open() {
@@ -605,7 +607,7 @@ mod tests {
 	}
 
 	#[test]
-	fn more_resolutions() {
+	fn more_resolutions1() {
 		let base_iri = Iri::new("http://a/bb/ccc/d;p?q").unwrap();
 
 		let tests = [
@@ -619,4 +621,41 @@ mod tests {
 			assert_eq!(buffer.as_str(), *absolute);
 		}
 	}
+
+	#[test]
+	fn more_resolutions2() {
+		let base_iri = Iri::new("http://a/bb/ccc/./d;p?q").unwrap();
+
+		let tests = [
+			("..", "http://a/bb/"),
+			("../", "http://a/bb/"),
+			("../g", "http://a/bb/g"),
+			("../..", "http://a/"),
+			("../../", "http://a/"),
+			("../../g", "http://a/g"),
+		];
+
+		for (relative, absolute) in &tests {
+			// println!("{} => {}", relative, absolute);
+			let buffer: crate::IriBuf = IriRef::new(relative).unwrap().resolved(base_iri);
+			assert_eq!(buffer.as_str(), *absolute);
+		}
+	}
+
+	#[test]
+	fn more_resolutions3() {
+		let base_iri = Iri::new("http://ab//de//ghi").unwrap();
+
+		let tests = [
+			("xyz", "http://ab//de//xyz"),
+			("./xyz", "http://ab//de//xyz"),
+			("../xyz", "http://ab//de/xyz"),
+		];
+
+		for (relative, absolute) in &tests {
+			// println!("{} => {}", relative, absolute);
+			let buffer: crate::IriBuf = IriRef::new(relative).unwrap().resolved(base_iri);
+			assert_eq!(buffer.as_str(), *absolute);
+		}
+	}
 }
